/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -a cvsjobadaptor -i cvsjob.h -l CvsJob /build/cervisia/src/cervisia-25.04.3/cvsservice/org.kde.cervisia5.cvsjob.xml
 *
 * qdbusxml2cpp is Copyright (C) 2023 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef CVSJOBADAPTOR_H
#define CVSJOBADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "cvsjob.h"
QT_BEGIN_NAMESPACE
class QByteArray;
template<class T> class QList;
template<class Key, class Value> class QMap;
class QString;
class QStringList;
class QVariant;
QT_END_NAMESPACE

/*
 * Adaptor class for interface org.kde.cervisia5.cvsservice.cvsjob
 */
class CvsjobAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.cervisia5.cvsservice.cvsjob")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.cervisia5.cvsservice.cvsjob\">\n"
"    <signal name=\"jobExited\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </signal>\n"
"    <signal name=\"receivedStdout\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </signal>\n"
"    <signal name=\"receivedStderr\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </signal>\n"
"    <method name=\"execute\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"cancel\"/>\n"
"    <method name=\"isRunning\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"cvsCommand\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"output\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    CvsjobAdaptor(CvsJob *parent);
    virtual ~CvsjobAdaptor();

    inline CvsJob *parent() const
    { return static_cast<CvsJob *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void cancel();
    QString cvsCommand();
    bool execute();
    bool isRunning();
    QStringList output();
Q_SIGNALS: // SIGNALS
    void jobExited(bool in0, int in1);
    void receivedStderr(const QString &in0);
    void receivedStdout(const QString &in0);
};

#endif
