/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -a repositoryadaptor -i repository.h -l Repository /build/cervisia/src/cervisia-25.04.3/cvsservice/org.kde.cervisia5.repository.xml
 *
 * qdbusxml2cpp is Copyright (C) 2023 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef REPOSITORYADAPTOR_H
#define REPOSITORYADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "repository.h"
QT_BEGIN_NAMESPACE
class QByteArray;
template<class T> class QList;
template<class Key, class Value> class QMap;
class QString;
class QStringList;
class QVariant;
QT_END_NAMESPACE

/*
 * Adaptor class for interface org.kde.cervisia5.repository
 */
class RepositoryAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.cervisia5.repository")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.cervisia5.repository\">\n"
"    <method name=\"cvsClient\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"clientOnly\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"rsh\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"server\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setWorkingCopy\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"dirName\"/>\n"
"    </method>\n"
"    <method name=\"workingCopy\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"location\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"retrieveCvsignoreFile\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    RepositoryAdaptor(Repository *parent);
    virtual ~RepositoryAdaptor();

    inline Repository *parent() const
    { return static_cast<Repository *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QString clientOnly();
    QString cvsClient();
    QString location();
    bool retrieveCvsignoreFile();
    QString rsh();
    QString server();
    bool setWorkingCopy(const QString &dirName);
    QString workingCopy();
Q_SIGNALS: // SIGNALS
};

#endif
