#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'settingsdialog_advanced.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGSDIALOG_ADVANCED_H
#define UI_SETTINGSDIALOG_ADVANCED_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_AdvancedPage
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *spacer2;
    QLabel *timeoutLbl;
    QLabel *compressionLbl;
    QCheckBox *kcfg_UseSshAgent;
    QSpinBox *kcfg_Compression;
    QSpinBox *kcfg_Timeout;

    void setupUi(QWidget *advancedPage)
    {
        if (advancedPage->objectName().isEmpty())
            advancedPage->setObjectName(QString::fromUtf8("advancedPage"));
        advancedPage->resize(575, 290);
        gridLayout = new QGridLayout(advancedPage);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        spacer2 = new QSpacerItem(31, 41, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(spacer2, 3, 1, 1, 1);

        timeoutLbl = new QLabel(advancedPage);
        timeoutLbl->setObjectName(QString::fromUtf8("timeoutLbl"));
        timeoutLbl->setWordWrap(false);

        gridLayout->addWidget(timeoutLbl, 0, 0, 1, 1);

        compressionLbl = new QLabel(advancedPage);
        compressionLbl->setObjectName(QString::fromUtf8("compressionLbl"));
        compressionLbl->setWordWrap(false);

        gridLayout->addWidget(compressionLbl, 1, 0, 1, 1);

        kcfg_UseSshAgent = new QCheckBox(advancedPage);
        kcfg_UseSshAgent->setObjectName(QString::fromUtf8("kcfg_UseSshAgent"));

        gridLayout->addWidget(kcfg_UseSshAgent, 2, 0, 1, 2);

        kcfg_Compression = new QSpinBox(advancedPage);
        kcfg_Compression->setObjectName(QString::fromUtf8("kcfg_Compression"));
        kcfg_Compression->setMinimum(0);
        kcfg_Compression->setMaximum(9);

        gridLayout->addWidget(kcfg_Compression, 1, 1, 1, 1);

        kcfg_Timeout = new QSpinBox(advancedPage);
        kcfg_Timeout->setObjectName(QString::fromUtf8("kcfg_Timeout"));
        kcfg_Timeout->setMinimum(0);
        kcfg_Timeout->setMaximum(50000);

        gridLayout->addWidget(kcfg_Timeout, 0, 1, 1, 1);

#if QT_CONFIG(shortcut)
        timeoutLbl->setBuddy(kcfg_Timeout);
        compressionLbl->setBuddy(kcfg_Compression);
#endif // QT_CONFIG(shortcut)

        retranslateUi(advancedPage);

        QMetaObject::connectSlotsByName(advancedPage);
    } // setupUi

    void retranslateUi(QWidget *advancedPage)
    {
        timeoutLbl->setText(tr2i18n("&Timeout after which a progress dialog appears (in ms):", nullptr));
        compressionLbl->setText(tr2i18n("Default compression &level:", nullptr));
        kcfg_UseSshAgent->setText(tr2i18n("Utilize a running or start a new ssh-agent process", nullptr));
        (void)advancedPage;
    } // retranslateUi

};

namespace Ui {
    class AdvancedPage: public Ui_AdvancedPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGSDIALOG_ADVANCED_H

