/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -a cvsserviceadaptor -i cvsservice.h -l CvsService /build/cervisia/src/cervisia-25.04.3/cvsservice/org.kde.cervisia5.cvsservice.xml
 *
 * qdbusxml2cpp is Copyright (C) 2023 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef CVSSERVICEADAPTOR_H
#define CVSSERVICEADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "cvsservice.h"
QT_BEGIN_NAMESPACE
class QByteArray;
template<class T> class QList;
template<class Key, class Value> class QMap;
class QString;
class QStringList;
class QVariant;
QT_END_NAMESPACE

/*
 * Adaptor class for interface org.kde.cervisia5.cvsservice.cvsservice
 */
class CvsserviceAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.cervisia5.cvsservice.cvsservice")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.cervisia5.cvsservice.cvsservice\">\n"
"    <method name=\"add\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"files\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"isBinary\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"addWatch\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"files\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"events\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"annotate\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"fileName\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"revision\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"checkout\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"workingDir\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"repository\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"module\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"tag\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"pruneDirs\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"checkout\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"workingDir\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"repository\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"module\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"tag\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"pruneDirs\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"alias\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"exportOnly\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"checkout\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"workingDir\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"repository\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"module\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"tag\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"pruneDirs\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"alias\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"exportOnly\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"recursive\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"commit\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"files\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"commitMessage\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"recursive\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"createRepository\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"repository\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"createTag\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"files\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"tag\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"branch\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"force\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"deleteTag\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"files\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"tag\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"branch\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"force\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"downloadCvsIgnoreFile\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"repository\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"outputFile\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"downloadRevision\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"fileName\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"revision\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"outputFile\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"downloadRevision\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"fileName\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"revA\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"outputFileA\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"revB\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"outputFileB\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"diff\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"fileName\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"revA\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"revB\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"diffOptions\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"context\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"diff\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"fileName\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"revA\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"revB\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"diffOptions\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"format\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"edit\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"files\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"editors\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"files\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"history\">\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"import\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"workingDir\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"repository\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"module\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"ignoreList\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"comment\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"vendorTag\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"releaseTag\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"importAsBinary\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"useModificationTime\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"lock\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"files\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"log\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"fileName\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"login\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"repository\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"logout\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"repository\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"makePatch\">\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"makePatch\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"diffOptions\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"format\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"moduleList\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"repository\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"remove\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"files\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"recursive\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"removeWatch\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"files\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"events\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"rlog\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"repository\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"module\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"recursive\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"simulateUpdate\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"files\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"recursive\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"createDirs\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"pruneDirs\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"status\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"files\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"recursive\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"tagInfo\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"unedit\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"files\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"unlock\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"files\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"update\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"files\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"recursive\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"createDirs\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"pruneDirs\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"extraOpt\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"watchers\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"files\"/>\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"quit\"/>\n"
"  </interface>\n"
        "")
public:
    CvsserviceAdaptor(CvsService *parent);
    virtual ~CvsserviceAdaptor();

    inline CvsService *parent() const
    { return static_cast<CvsService *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QDBusObjectPath add(const QStringList &files, bool isBinary);
    QDBusObjectPath addWatch(const QStringList &files, int events);
    QDBusObjectPath annotate(const QString &fileName, const QString &revision);
    QDBusObjectPath checkout(const QString &workingDir, const QString &repository, const QString &module, const QString &tag, bool pruneDirs, const QString &alias, bool exportOnly, bool recursive);
    QDBusObjectPath checkout(const QString &workingDir, const QString &repository, const QString &module, const QString &tag, bool pruneDirs, const QString &alias, bool exportOnly);
    QDBusObjectPath checkout(const QString &workingDir, const QString &repository, const QString &module, const QString &tag, bool pruneDirs);
    QDBusObjectPath commit(const QStringList &files, const QString &commitMessage, bool recursive);
    QDBusObjectPath createRepository(const QString &repository);
    QDBusObjectPath createTag(const QStringList &files, const QString &tag, bool branch, bool force);
    QDBusObjectPath deleteTag(const QStringList &files, const QString &tag, bool branch, bool force);
    QDBusObjectPath diff(const QString &fileName, const QString &revA, const QString &revB, const QString &diffOptions, const QString &format);
    QDBusObjectPath diff(const QString &fileName, const QString &revA, const QString &revB, const QString &diffOptions, uint context);
    QDBusObjectPath downloadCvsIgnoreFile(const QString &repository, const QString &outputFile);
    QDBusObjectPath downloadRevision(const QString &fileName, const QString &revA, const QString &outputFileA, const QString &revB, const QString &outputFileB);
    QDBusObjectPath downloadRevision(const QString &fileName, const QString &revision, const QString &outputFile);
    QDBusObjectPath edit(const QStringList &files);
    QDBusObjectPath editors(const QStringList &files);
    QDBusObjectPath history();
    QDBusObjectPath import(const QString &workingDir, const QString &repository, const QString &module, const QString &ignoreList, const QString &comment, const QString &vendorTag, const QString &releaseTag, bool importAsBinary, bool useModificationTime);
    QDBusObjectPath lock(const QStringList &files);
    QDBusObjectPath log(const QString &fileName);
    QDBusObjectPath login(const QString &repository);
    QDBusObjectPath logout(const QString &repository);
    QDBusObjectPath makePatch(const QString &diffOptions, const QString &format);
    QDBusObjectPath makePatch();
    QDBusObjectPath moduleList(const QString &repository);
    void quit();
    QDBusObjectPath remove(const QStringList &files, bool recursive);
    QDBusObjectPath removeWatch(const QStringList &files, int events);
    QDBusObjectPath rlog(const QString &repository, const QString &module, bool recursive);
    QDBusObjectPath simulateUpdate(const QStringList &files, bool recursive, bool createDirs, bool pruneDirs);
    QDBusObjectPath status(const QStringList &files, bool recursive, bool tagInfo);
    QDBusObjectPath unedit(const QStringList &files);
    QDBusObjectPath unlock(const QStringList &files);
    QDBusObjectPath update(const QStringList &files, bool recursive, bool createDirs, bool pruneDirs, const QString &extraOpt);
    QDBusObjectPath watchers(const QStringList &files);
Q_SIGNALS: // SIGNALS
};

#endif
