/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -a protocolviewadaptor -i protocolview.h -l ProtocolView /build/cervisia/src/cervisia-25.04.3/org.kde.cervisia5.protocolview.xml
 *
 * qdbusxml2cpp is Copyright (C) 2023 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef PROTOCOLVIEWADAPTOR_H
#define PROTOCOLVIEWADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "protocolview.h"
QT_BEGIN_NAMESPACE
class QByteArray;
template<class T> class QList;
template<class Key, class Value> class QMap;
class QString;
class QStringList;
class QVariant;
QT_END_NAMESPACE

/*
 * Adaptor class for interface org.kde.cervisia5.protocolview
 */
class ProtocolviewAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.cervisia5.protocolview")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.cervisia5.protocolview\">\n"
"    <method name=\"slotReceivedOutput\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"buffer\"/>\n"
"    </method>\n"
"    <method name=\"slotJobExited\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"normalExit\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"exitStatus\"/>\n"
"    </method>\n"
"    <signal name=\"receivedLine\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"line\"/>\n"
"    </signal>\n"
"    <signal name=\"jobFinished\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"normalExit\"/>\n"
"      <arg direction=\"out\" type=\"i\" name=\"exitStatus\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    ProtocolviewAdaptor(ProtocolView *parent);
    virtual ~ProtocolviewAdaptor();

    inline ProtocolView *parent() const
    { return static_cast<ProtocolView *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void slotJobExited(bool normalExit, int exitStatus);
    void slotReceivedOutput(const QString &buffer);
Q_SIGNALS: // SIGNALS
    void jobFinished(bool normalExit, int exitStatus);
    void receivedLine(const QString &line);
};

#endif
