/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -a cvsloginjobadaptor -i cvsloginjob.h -l CvsLoginJob /build/cervisia/src/cervisia-25.04.3/cvsservice/org.kde.cervisia5.cvsloginjob.xml
 *
 * qdbusxml2cpp is Copyright (C) 2023 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef CVSLOGINJOBADAPTOR_H
#define CVSLOGINJOBADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "cvsloginjob.h"
QT_BEGIN_NAMESPACE
class QByteArray;
template<class T> class QList;
template<class Key, class Value> class QMap;
class QString;
class QStringList;
class QVariant;
QT_END_NAMESPACE

/*
 * Adaptor class for interface org.kde.cervisia5.cvsservice.cvsloginjob
 */
class CvsloginjobAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.cervisia5.cvsservice.cvsloginjob")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.cervisia5.cvsservice.cvsloginjob\">\n"
"    <method name=\"output\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"execute\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    CvsloginjobAdaptor(CvsLoginJob *parent);
    virtual ~CvsloginjobAdaptor();

    inline CvsLoginJob *parent() const
    { return static_cast<CvsLoginJob *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    bool execute();
    QStringList output();
Q_SIGNALS: // SIGNALS
};

#endif
