/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -p repositoryinterface /build/cervisia/src/cervisia-25.04.3/cvsservice/org.kde.cervisia5.repository.xml
 *
 * qdbusxml2cpp is Copyright (C) 2023 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef REPOSITORYINTERFACE_H
#define REPOSITORYINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.cervisia5.repository
 */
class OrgKdeCervisia5RepositoryInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.cervisia5.repository"; }

public:
    OrgKdeCervisia5RepositoryInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeCervisia5RepositoryInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QString> clientOnly()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("clientOnly"), argumentList);
    }

    inline QDBusPendingReply<QString> cvsClient()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("cvsClient"), argumentList);
    }

    inline QDBusPendingReply<QString> location()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("location"), argumentList);
    }

    inline QDBusPendingReply<bool> retrieveCvsignoreFile()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("retrieveCvsignoreFile"), argumentList);
    }

    inline QDBusPendingReply<QString> rsh()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("rsh"), argumentList);
    }

    inline QDBusPendingReply<QString> server()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("server"), argumentList);
    }

    inline QDBusPendingReply<bool> setWorkingCopy(const QString &dirName)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(dirName);
        return asyncCallWithArgumentList(QStringLiteral("setWorkingCopy"), argumentList);
    }

    inline QDBusPendingReply<QString> workingCopy()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("workingCopy"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace kde {
    namespace cervisia5 {
      typedef ::OrgKdeCervisia5RepositoryInterface repository;
    }
  }
}
#endif
