/****************************************************************************
** Meta object code from reading C++ file 'logdialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../cervisia-25.04.3/logdialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'logdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_LogDialog_t {
    QByteArrayData data[16];
    char stringdata0[147];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_LogDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_LogDialog_t qt_meta_stringdata_LogDialog = {
    {
QT_MOC_LITERAL(0, 0, 9), // "LogDialog"
QT_MOC_LITERAL(1, 10, 6), // "slotOk"
QT_MOC_LITERAL(2, 17, 0), // ""
QT_MOC_LITERAL(3, 18, 9), // "slotPatch"
QT_MOC_LITERAL(4, 28, 8), // "slotHelp"
QT_MOC_LITERAL(5, 37, 11), // "findClicked"
QT_MOC_LITERAL(6, 49, 11), // "diffClicked"
QT_MOC_LITERAL(7, 61, 15), // "annotateClicked"
QT_MOC_LITERAL(8, 77, 16), // "revisionSelected"
QT_MOC_LITERAL(9, 94, 3), // "rev"
QT_MOC_LITERAL(10, 98, 3), // "rmb"
QT_MOC_LITERAL(11, 102, 12), // "tagASelected"
QT_MOC_LITERAL(12, 115, 1), // "n"
QT_MOC_LITERAL(13, 117, 12), // "tagBSelected"
QT_MOC_LITERAL(14, 130, 10), // "tabChanged"
QT_MOC_LITERAL(15, 141, 5) // "index"

    },
    "LogDialog\0slotOk\0\0slotPatch\0slotHelp\0"
    "findClicked\0diffClicked\0annotateClicked\0"
    "revisionSelected\0rev\0rmb\0tagASelected\0"
    "n\0tagBSelected\0tabChanged\0index"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_LogDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x09 /* Protected */,
       3,    0,   65,    2, 0x09 /* Protected */,
       4,    0,   66,    2, 0x09 /* Protected */,
       5,    0,   67,    2, 0x08 /* Private */,
       6,    0,   68,    2, 0x08 /* Private */,
       7,    0,   69,    2, 0x08 /* Private */,
       8,    2,   70,    2, 0x08 /* Private */,
      11,    1,   75,    2, 0x08 /* Private */,
      13,    1,   78,    2, 0x08 /* Private */,
      14,    1,   81,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,    9,   10,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, QMetaType::Int,   15,

       0        // eod
};

void LogDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<LogDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->slotOk(); break;
        case 1: _t->slotPatch(); break;
        case 2: _t->slotHelp(); break;
        case 3: _t->findClicked(); break;
        case 4: _t->diffClicked(); break;
        case 5: _t->annotateClicked(); break;
        case 6: _t->revisionSelected((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 7: _t->tagASelected((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->tagBSelected((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->tabChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject LogDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_LogDialog.data,
    qt_meta_data_LogDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *LogDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LogDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_LogDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int LogDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
